@@ -19,9 +19,10 @@ class Job:
         output_path: Path,
         batch_size: int,
         n_workers: int,
+        gpu: bool,
     ):
         self.cfg = cfg
-        self.device = "cuda" if torch.cuda.is_available() else "cpu"
+        self.device = "cuda" if torch.cuda.is_available() and gpu else "cpu"
         self.output_path = output_path
         self.aligner = align.Aligner.build(self.device, cfg)
         self.loader = DataLoader(
@@ -34,8 +35,8 @@ class Job:
 
     def run(self):
         total = len(self.loader)
-        for i, (xs, ys, ids) in tqdm(enumerate(self.loader), total=total):
-            alignments = self.aligner.align((xs, ys))
+        for xs, ys, ys_original, ids in tqdm(self.loader, total=total):
+            alignments = self.aligner.align((xs, ys, ys_original))
 
             # write the alignments
             for i, id in enumerate(ids):
